A separately posted I-pipe patch refactors the tickdev emulation API.
This patch updates Xenomai to the new prototypes without changing any
functionality.

Jan
---
 include/asm-generic/bits/pod.h |   14 +++++++-------
 include/asm-generic/hal.h      |    6 +++---
 ksrc/arch/generic/hal.c        |    4 ++--
 ksrc/arch/x86/hal-shared.c     |    6 +++---
 ksrc/arch/x86/hal_32.c         |    4 ++--
 5 files changed, 17 insertions(+), 17 deletions(-)

Index: xenomai/include/asm-generic/hal.h
===================================================================
--- xenomai.orig/include/asm-generic/hal.h
+++ xenomai/include/asm-generic/hal.h
@@ -440,12 +440,12 @@ unsigned long rthal_timer_calibrate(void
 
 #ifdef CONFIG_GENERIC_CLOCKEVENTS
 int rthal_timer_request(void (*tick_handler)(void),
-			void (*mode_emul)(enum clock_event_mode mode, struct ipipe_tick_device *tdev),
-			int (*tick_emul) (unsigned long delay, struct ipipe_tick_device *tdev),
+			void (*mode_emul)(enum clock_event_mode mode, struct clock_event_device *cdev),
+			int (*tick_emul) (unsigned long delay, struct clock_event_device *cdev),
 			int cpu);
 
 void rthal_timer_notify_switch(enum clock_event_mode mode,
-			       struct ipipe_tick_device *tdev);
+			       struct clock_event_device *cdev);
 
 #else
 int rthal_timer_request(void (*tick_handler)(void),
Index: xenomai/ksrc/arch/generic/hal.c
===================================================================
--- xenomai.orig/ksrc/arch/generic/hal.c
+++ xenomai/ksrc/arch/generic/hal.c
@@ -985,8 +985,8 @@ unsigned long long __rthal_generic_full_
 
 /**
  * \fn int rthal_timer_request(void (*tick_handler)(void),
- *             void (*mode_emul)(enum clock_event_mode mode, struct ipipe_tick_device *tdev),
- *             int (*tick_emul)(unsigned long delay, struct ipipe_tick_device *tdev), int cpu)
+ *             void (*mode_emul)(enum clock_event_mode mode, struct clock_event_device *cdev),
+ *             int (*tick_emul)(unsigned long delay, struct clock_event_device *cdev), int cpu)
  * \brief Grab the hardware timer.
  *
  * rthal_timer_request() grabs and tunes the hardware timer in oneshot
Index: xenomai/ksrc/arch/x86/hal-shared.c
===================================================================
--- xenomai.orig/ksrc/arch/x86/hal-shared.c
+++ xenomai/ksrc/arch/x86/hal-shared.c
@@ -121,9 +121,9 @@ int rthal_timer_request(
 	void (*tick_handler)(void),
 #ifdef CONFIG_GENERIC_CLOCKEVENTS
 	void (*mode_emul)(enum clock_event_mode mode,
-			  struct ipipe_tick_device *tdev),
+			  struct clock_event_device *cdev),
 	int (*tick_emul)(unsigned long delay,
-			 struct ipipe_tick_device *tdev),
+			 struct clock_event_device *cdev),
 #endif
 	int cpu)
 {
@@ -238,7 +238,7 @@ void rthal_timer_release(int cpu)
 #ifdef CONFIG_GENERIC_CLOCKEVENTS
 
 void rthal_timer_notify_switch(enum clock_event_mode mode,
-			       struct ipipe_tick_device *tdev)
+			       struct clock_event_device *cdev)
 {
 	if (rthal_processor_id() > 0)
 		/*
Index: xenomai/ksrc/arch/x86/hal_32.c
===================================================================
--- xenomai.orig/ksrc/arch/x86/hal_32.c
+++ xenomai/ksrc/arch/x86/hal_32.c
@@ -231,9 +231,9 @@ int rthal_timer_request(
 	void (*tick_handler)(void),
 #ifdef CONFIG_GENERIC_CLOCKEVENTS
 	void (*mode_emul)(enum clock_event_mode mode,
-			  struct ipipe_tick_device *tdev),
+			  struct clock_event_device *cdev),
 	int (*tick_emul)(unsigned long delay,
-			 struct ipipe_tick_device *tdev),
+			 struct clock_event_device *cdev),
 #endif
 	int cpu)
 {

Attachment: signature.asc
Description: OpenPGP digital signature

_______________________________________________
Xenomai-core mailing list
Xenomai-core@gna.org
https://mail.gna.org/listinfo/xenomai-core

Reply via email to
Index: xenomai/include/asm-generic/bits/pod.h
===================================================================
--- xenomai.orig/include/asm-generic/bits/pod.h
+++ xenomai/include/asm-generic/bits/pod.h
@@ -31,7 +31,7 @@
 
 /*!
  * @internal
  * \fn void xnarch_next_htick_shot(unsigned long delay, struct ipipe_tick_device *tdev)
  *
  * \brief Next tick setup emulation callback.
  *
@@ -42,7 +42,7 @@
  * @param delay The time delta from the current date to the next tick,
  * expressed as a count of nanoseconds.
  *
  * @param tdev An pointer to the tick device which notifies us.
  *
  * Environment:
  *
@@ -58,7 +58,7 @@
  * Rescheduling: never.
  */
 
-static int xnarch_next_htick_shot(unsigned long delay, struct ipipe_tick_device *tdev)
+static int xnarch_next_htick_shot(unsigned long delay, struct clock_event_device *cdev)
 {
 	xnsched_t *sched;
 	spl_t s;
@@ -73,7 +73,7 @@ static int xnarch_next_htick_shot(unsign
 
 /*!
  * @internal
  * \fn void xnarch_switch_htick_mode(enum clock_event_mode mode, struct ipipe_tick_device *tdev)
  *
  * \brief Tick mode switch emulation callback.
  *
@@ -94,7 +94,7 @@ static int xnarch_next_htick_shot(unsign
  * which should never be shut down, so this mode should not be
  * encountered.
  *
  * @param tdev An opaque pointer to the tick device which notifies us.
  *
  * Environment:
  *
@@ -109,13 +109,13 @@ static int xnarch_next_htick_shot(unsign
  * Rescheduling: never.
  */
 
-static void xnarch_switch_htick_mode(enum clock_event_mode mode, struct ipipe_tick_device *tdev)
+static void xnarch_switch_htick_mode(enum clock_event_mode mode, struct clock_event_device *cdev)
 {
 	xnsched_t *sched;
 	xnticks_t tickval;
 	spl_t s;
 
-	rthal_timer_notify_switch(mode, tdev);
+	rthal_timer_notify_switch(mode, cdev);
 
 	if (mode == CLOCK_EVT_MODE_ONESHOT)
 		return;
@@ -31,7 +31,7 @@
 /*!
  * @internal
- * \fn void xnarch_next_htick_shot(unsigned long delay, struct ipipe_tick_device *tdev)
+ * \fn void xnarch_next_htick_shot(unsigned long delay, struct clock_event_device *cdev)
  *
  * \brief Next tick setup emulation callback.
@@ -42,7 +42,7 @@
  * expressed as a count of nanoseconds.
  *
- * @param tdev An pointer to the tick device which notifies us.
+ * @param cdev An pointer to the clock device which notifies us.
  *
  * Environment:
@@ -73,7 +73,7 @@ static int xnarch_next_htick_shot(unsign
 /*!
  * @internal
- * \fn void xnarch_switch_htick_mode(enum clock_event_mode mode, struct ipipe_tick_device *tdev)
+ * \fn void xnarch_switch_htick_mode(enum clock_event_mode mode, struct clock_event_device *cdev)
  *
  * \brief Tick mode switch emulation callback.
@@ -94,7 +94,7 @@ static int xnarch_next_htick_shot(unsign
  * encountered.
  *
- * @param tdev An opaque pointer to the tick device which notifies us.
+ * @param cdev An opaque pointer to the clock device which notifies us.
  *
  * Environment: